@@ -5,8 +5,11 @@ from ..htmlhelpers import *
 from ..messages import *
 
 def requiredIDs(doc):
+	if not doc.md.requiredIDs:
+		return
+	doc_ids = {e.get("id") for e in findAll("[id]", doc)}
 	for id in doc.md.requiredIDs:
 		if id.startswith("#"):
 			id = id[1:]
-		if find("#{0}".format(escapeCSSIdent(id)), doc) is None:
-			die("Required ID '{0}' was not found in the document.", id)
\ No newline at end of file
+		if id not in doc_ids:
+			die("Required ID '{0}' was not found in the document.", id)
