@@ -2,6 +2,7 @@
 
 
 import difflib
+import glob
 import io
 import os
 import pipes
@@ -113,13 +114,10 @@ def equalOrEmpty(a, b):
 
 def rebase(Spec, files=None, md=None):
     fileRequester = config.DataFileRequester(type="readonly")
-    if not files:
-        files = list(sortTests(findTestFiles()))
-        if len(files) == 0:
-            p("No tests were found")
-            return True
-    else:
-        files = [os.path.join(TEST_DIR, x) for x in files]
+    files = testPaths(files)
+    if len(files) == 0:
+        p("No tests were found.")
+        return True
     for i,path in enumerate(files, 1):
         justifiedI = str(i).rjust(len(str(len(files))))
         resetSeenMessages()
@@ -132,7 +130,23 @@ def rebase(Spec, files=None, md=None):
         doc.preprocess()
         doc.finish()
 
+def testPaths(files=None):
+    # if None, get all the test paths
+    # otherwise, glob the provided paths, rooted at the test dir
+    if not files:
+        return list(sortTests(findTestFiles()))
+    else:
+        return [path
+            for file in files
+            for path in glob.glob(os.path.join(TEST_DIR, file))
+            if path.endswith(".bs")]
+
 def addTestMetadata(doc):
+    from . import metadata
+
     doc.mdBaseline.addData("Boilerplate", "omit feedback-header, omit generator, omit document-revision")
-    doc.mdCommandLine.addData("Date", "1970-01-01")
-    doc.mdCommandLine.addData("Inline Github Issues", "no")
+    _, md = metadata.parse(lines=doc.lines)
+    if "Date" not in md.manuallySetKeys:
+        doc.mdCommandLine.addData("Date", "1970-01-01")
+    if "Inline Github Issue" not in md.manuallySetKeys:
+        doc.mdCommandLine.addData("Inline Github Issues", "no")
